/* eslint-env jest */
import SdsInputCheckbox from '../input-checkbox';
import * as utils from '../../../../../.jest/utils';
customElements.define('sds-input-checkbox', SdsInputCheckbox);

describe('sds-input-checkbox', () => {
  afterEach(() => {
    // The jsdom instance is shared across test cases in a single file so reset the DOM
    while (document.body.firstChild) {
      document.body.removeChild(document.body.firstChild);
    }
  });

  it('contains 4 named parts with the values "input-checkbox", "checkbox", "indicator", and "label".', async () => {
    const element = utils.renderIntoBody(`<sds-input-checkbox>Checkbox</sds-input-checkbox>`);
    const container = element.shadowRoot.querySelector('[part="input-checkbox"]');
    const checkbox = element.shadowRoot.querySelector('[part="checkbox"]');
    const indicator = element.shadowRoot.querySelector('[part="indicator"]');
    const label = element.shadowRoot.querySelector('[part="label"]');
    expect(container).toBeInTheDocument();
    expect(checkbox).toBeInTheDocument();
    expect(indicator).toBeInTheDocument();
    expect(label).toBeInTheDocument();
  });

  it('contains 1 named slot with the value "indicator"', async () => {
    const element = utils.renderIntoBody(`<sds-input-checkbox>Checkbox</sds-input-checkbox>`);
    const indicator = element.shadowRoot.querySelector('[name="indicator"]');
    expect(indicator).toBeInTheDocument();
  });

  it('renders default slot content', async () => {
    const element = utils.renderIntoBody(
      `<sds-input-checkbox><span id="default-slot-content">Checkbox</span></sds-input-checkbox>`,
    );
    const defaultContent = element.querySelector('#default-slot-content');
    expect(defaultContent).toBeInTheDocument();
  });

  it('sets a default "check" indicator', async () => {
    const element = utils.renderIntoBody(`<sds-input-checkbox>Checkbox</sds-input-checkbox>`);
    const icon = element.shadowRoot.querySelector('sds-icon');
    expect(icon).toHaveAttribute('symbol', 'check');
  });

  it('sets a default "dash" indeterminate indicator', async () => {
    const element = utils.renderIntoBody(`<sds-input-checkbox indeterminate>Checkbox</sds-input-checkbox>`);
    const icon = element.shadowRoot.querySelector('sds-icon');
    expect(icon).toHaveAttribute('symbol', 'dash');
  });

  it('sets default checked content attribute on host and input', async () => {
    const element = utils.renderIntoBody(`<sds-input-checkbox checked>Checkbox</sds-input-checkbox>`);
    const checkbox = element.shadowRoot.querySelector('[part~="checkbox"]');
    expect(element).toHaveAttribute('checked');
    expect(checkbox).toHaveAttribute('checked');
  });

  it('sets indeterminate content attribute on host and IDL property on input', async () => {
    const element = utils.renderIntoBody(`<sds-input-checkbox indeterminate>Checkbox</sds-input-checkbox>`);
    const checkbox = element.shadowRoot.querySelector('[part~="checkbox"]');
    expect(element).toHaveAttribute('indeterminate');
    expect(checkbox).toHaveProperty('indeterminate');
  });

  it('sets disabled content attribute on host and input', async () => {
    const element = utils.renderIntoBody(`<sds-input-checkbox disabled>Checkbox</sds-input-checkbox>`);
    const checkbox = element.shadowRoot.querySelector('[part~="checkbox"]');
    expect(element).toHaveAttribute('disabled');
    expect(checkbox).toHaveAttribute('disabled');
  });

  it('sets required content attribute on host and input', async () => {
    const element = utils.renderIntoBody(`<sds-input-checkbox required>Checkbox</sds-input-checkbox>`);
    const checkbox = element.shadowRoot.querySelector('[part~="checkbox"]');
    expect(element).toHaveAttribute('required');
    expect(checkbox).toHaveAttribute('required');
  });

  it('delegates name content attribute on host to input', async () => {
    const element = utils.renderIntoBody(
      `<sds-input-checkbox name="example-name">Checkbox</sds-input-checkbox>`,
    );
    const checkbox = element.shadowRoot.querySelector('[part~="checkbox"]');
    expect(checkbox).toHaveAttribute('name', 'example-name');
  });

  it('delegates value content attribute on host to input', async () => {
    const element = utils.renderIntoBody(
      `<sds-input-checkbox value="example-value">Checkbox</sds-input-checkbox>`,
    );
    const checkbox = element.shadowRoot.querySelector('[part~="checkbox"]');
    expect(checkbox).toHaveAttribute('value', 'example-value');
  });

  it('delegates id content attribute on host to input and label', async () => {
    const element = utils.renderIntoBody(`<sds-input-checkbox id="example-id">Checkbox</sds-input-checkbox>`);
    const checkbox = element.shadowRoot.querySelector('[part~="checkbox"]');
    const label = element.shadowRoot.querySelector('[part~="label"]');
    expect(checkbox).toHaveAttribute('id', 'example-id');
    expect(label).toHaveAttribute('for', 'example-id');
  });

  it('sets a custom indicator', async () => {
    const element = utils.renderIntoBody(
      `<sds-input-checkbox indicator="activity">Checkbox</sds-input-checkbox>`,
    );
    const icon = element.shadowRoot.querySelector('sds-icon');
    expect(element).toHaveAttribute('indicator', 'activity');
    expect(icon).toHaveAttribute('symbol', 'activity');
  });

  it('sets a custom indeterminate indicator', async () => {
    const element = utils.renderIntoBody(
      `<sds-input-checkbox indeterminate indeterminate-indicator="activity">Checkbox</sds-input-checkbox>`,
    );
    const icon = element.shadowRoot.querySelector('sds-icon');
    expect(element).toHaveAttribute('indeterminate-indicator', 'activity');
    expect(icon).toHaveAttribute('symbol', 'activity');
  });
});
