/* Copyright (c) 2015-present, salesforce.com, inc. All rights reserved
Licensed under BSD 3-Clause - see LICENSE.txt or git.io/sfdc-license */

import SdsInputCheckboxSpec from './input-checkbox.spec.md';
import SdsInputCheckbox from './input-checkbox';

export default {
  title: 'Salesforce Design System/Components/Input Checkbox',
  component: SdsInputCheckbox,
  argTypes: {
    checked: {
      control: {
        type: 'boolean',
      },
      defaultValue: false,
      table: {
        category: 'Attributes',
      },
    },
    indeterminate: {
      control: {
        type: 'boolean',
      },
      defaultValue: false,
      table: {
        category: 'Attributes',
      },
    },
    disabled: {
      control: {
        type: 'boolean',
      },
      defaultValue: false,
      table: {
        category: 'Attributes',
      },
    },
    required: {
      control: {
        type: 'boolean',
      },
      defaultValue: false,
      table: {
        category: 'Attributes',
      },
    },
    indicator: {
      control: {
        type: 'text',
      },
      table: {
        category: 'Attributes',
      },
    },
    name: {
      control: {
        type: 'text',
      },
      defaultValue: 'example-name',
      table: {
        category: 'Attributes',
      },
    },
    value: {
      control: {
        type: 'text',
      },
      defaultValue: 'example-value',
      table: {
        category: 'Attributes',
      },
    },
    id: {
      control: {
        type: 'text',
      },
      defaultValue: 'example-id',
      table: {
        category: 'Attributes',
      },
    },
    '--sds-c-inputcheckbox-sizing': {
      control: { type: 'number' },
      defaultValue: 16,
      table: {
        category: 'StylingHooks (preview)',
      },
    },
    '--sds-c-inputcheckbox-label-spacing-inline-start': {
      control: { type: 'number' },
      defaultValue: 8,
      table: {
        category: 'StylingHooks (preview)',
      },
    },
  },
};

export const Spec = () => `
  <sds-guideline-wrapper>
    ${SdsInputCheckboxSpec}
  </sds-guideline-wrapper>
`;

Spec.parameters = {
  eyes: { include: false },
};

export const Base = (args) => `
  <div style="
    --sds-c-inputcheckbox-sizing: ${args['--sds-c-inputcheckbox-sizing']}px;
    --sds-c-inputcheckbox-label-spacing-inline-start: ${
      args['--sds-c-inputcheckbox-label-spacing-inline-start']
    }px;
  ">
    <sds-input-checkbox
      ${args.checked ? 'checked' : ''}
      ${args.indeterminate ? 'indeterminate' : ''}
      ${args.disabled ? 'disabled' : ''}
      ${args.required ? 'required' : ''}
      name=${args.name}
      value=${args.value}
      id=${args.id}
      ${args.indicator ? `indicator=${args.indicator}` : ''}
    >Checkbox</sds-input-checkbox>
  </div>
`;
